/***********************************************************************************************************************
* DISCLAIMER
* This software is supplied by Renesas Electronics Corporation and is only intended for use with Renesas products.
* No other uses are authorized. This software is owned by Renesas Electronics Corporation and is protected under all
* applicable laws, including copyright laws.
* THIS SOFTWARE IS PROVIDED "AS IS" AND RENESAS MAKES NO WARRANTIESREGARDING THIS SOFTWARE, WHETHER EXPRESS, IMPLIED
* OR STATUTORY, INCLUDING BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
* NON-INFRINGEMENT.  ALL SUCH WARRANTIES ARE EXPRESSLY DISCLAIMED.TO THE MAXIMUM EXTENT PERMITTED NOT PROHIBITED BY
* LAW, NEITHER RENESAS ELECTRONICS CORPORATION NOR ANY OF ITS AFFILIATED COMPANIES SHALL BE LIABLE FOR ANY DIRECT,
* INDIRECT, SPECIAL, INCIDENTAL OR CONSEQUENTIAL DAMAGES FOR ANY REASON RELATED TO THIS SOFTWARE, EVEN IF RENESAS OR
* ITS AFFILIATES HAVE BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGES.
* Renesas reserves the right, without notice, to make changes to this software and to discontinue the availability
* of this software. By using this software, you agree to the additional terms and conditions found by accessing the
* following link:
* http://www.renesas.com/disclaimer
*
* Copyright (C) 2015, 2017 Renesas Electronics Corporation. All rights reserved.
***********************************************************************************************************************/

/*******************************************************************************
* File Name : tb_rx65n_main.c
* Version : 1.02
* Device(s) : R5F565NEDDFP
* Tool-Chain : CC-RX v2.07.00
* Smart Configurator : v1.2.0
* H/W Platform : Target Board for RX65N
* Description : The function of this program selects either the user switch
*               interrupt or the timer interrupt according to the mode
*               selection at startup and controls the lighting of the LED by
*               using the interrupt.
* Operation : Auto mode : (1-1) Power on reset.
*                         (1-2) LED0, LED1 blink alternate.(interval 500 ms)
*             Manual mode : (2-1) Press down SW1 button with reset.
*                           (2-2) When SW1 is clicked, LED0, LED1 blink
*                                 alternately.
******************************************************************************/

/*****************************************************************************
* History : 01.08.2017 Version Description
* : 01.08.2017 1.00 First Release
* : 14.09.2017 1.01 Header information fix.
*                   Adds Include File [tbrx651def.h].
*                   Changed to processing using include file declaration.
* : 27.09.2017 1.02 Changed device RX651 -> RX65N.
*                   Fix user define file location.
*                   (Config_CMT0_user.c, Config_ICU_user.c)
*
******************************************************************************/
#include <tbrx65ndef.h>
#include "r_smc_entry.h"
#include "Config_SCI6.h"
#include "Config_CMT0.h"
#include "Config_PORT.h"

uint8_t msg1_buf[3] = { "aa" };
uint8_t msg2_buf[59] = { "  TEND flag: before TDR write=- after TDR write=-,-,-,-\r\n" };
#define MSG2_POS_BEF 30
#define MSG2_POS_AFT 48
volatile uint8_t tick;
volatile uint8_t tend;
volatile uint8_t TEND_sampling[5];

void main(void);

/***********************************************************************************************************************
* Function Name: main
* Description  : This function implements main function.
* Arguments    : None
* Return Value : None
***********************************************************************************************************************/
void main(void)
{
    LED0 = LED_OFF;
    LED1 = LED_OFF;

    tick = 0;

    R_Config_SCI6_Start();
    R_Config_CMT0_Start();

    while(1)
    {
        ; /* Blink LED0, LED1 Alternately by Interrupt */

        while (tick % 2 == 0)
        {
            ;
        }
        tend = 0;

        R_Config_SCI6_Serial_Send(msg1_buf, 1);
        //R_Config_SCI6_Serial_Send(msg1_buf, 2);

        while (tick % 2 == 1)
        {
            ;
        }
        if (tend == 1)
        {
            msg1_buf[0] = (msg1_buf[0] < 'z') ? msg1_buf[0] + 1 : 'a';
            msg1_buf[1] = (msg1_buf[1] < 'z') ? msg1_buf[1] + 1 : 'a';
        }

        msg2_buf[MSG2_POS_BEF+0] = (TEND_sampling[0] & 0x04) == 0 ? '0' : '1';
        msg2_buf[MSG2_POS_AFT+0] = (TEND_sampling[1] & 0x04) == 0 ? '0' : '1';
        msg2_buf[MSG2_POS_AFT+2] = (TEND_sampling[2] & 0x04) == 0 ? '0' : '1';
        msg2_buf[MSG2_POS_AFT+4] = (TEND_sampling[3] & 0x04) == 0 ? '0' : '1';
        msg2_buf[MSG2_POS_AFT+6] = (TEND_sampling[4] & 0x04) == 0 ? '0' : '1';
        R_Config_SCI6_Serial_Send(msg2_buf, 58);
    }
}
